==> xlniuxdata-vipgame-1.0.2-20150210.053540-6-sources.jar: com/xunlei/niux/data/vipgame/vo/mobilegameapkversion/MobileGameChannelApk.java <==
package com.xunlei.niux.data.vipgame.vo.mobilegameapkversion;

import com.ferret.common.dao.annotation.Table;

@Table(tableName="mobileGameChannelApk",pkFieldName="channelApkId")
public class MobileGameChannelApk {
	private Long channelApkId;
	private Long apkId;
	private String channelId;
	private String channelApkName;
	private String packageTime;
	private String downLoadLink;
	private String channleApkStatus;
	private String testUser;
	private String testTime;
	private String submitTestRemark;
	private String testRemark;
	private String muliPhotoUrl;
	
	
	public String getMuliPhotoUrl() {
		return muliPhotoUrl;
	}
	public void setMuliPhotoUrl(String muliPhotoUrl) {
		this.muliPhotoUrl = muliPhotoUrl;
	}
	public Long getChannelApkId() {
		return channelApkId;
	}
	public void setChannelApkId(Long channelApkId) {
		this.channelApkId = channelApkId;
	}
	public Long getApkId() {
		return apkId;
	}
	public void setApkId(Long apkId) {
		this.apkId = apkId;
	}
	public String getChannelId() {
		return channelId;
	}
	public void setChannelId(String channelId) {
		this.channelId = channelId;
	}
	public String getChannelApkName() {
		return channelApkName;
	}
	public void setChannelApkName(String channelApkName) {
		this.channelApkName = channelApkName;
	}
	public String getPackageTime() {
		return packageTime;
	}
	public void setPackageTime(String packageTime) {
		this.packageTime = packageTime;
	}
	public String getDownLoadLink() {
		return downLoadLink;
	}
	public void setDownLoadLink(String downLoadLink) {
		this.downLoadLink = downLoadLink;
	}
	public String getChannleApkStatus() {
		return channleApkStatus;
	}
	public void setChannleApkStatus(String channleApkStatus) {
		this.channleApkStatus = channleApkStatus;
	}
	public String getTestUser() {
		return testUser;
	}
	public void setTestUser(String testUser) {
		this.testUser = testUser;
	}
	public String getTestTime() {
		return testTime;
	}
	public void setTestTime(String testTime) {
		this.testTime = testTime;
	}
	public String getSubmitTestRemark() {
		return submitTestRemark;
	}
	public void setSubmitTestRemark(String submitTestRemark) {
		this.submitTestRemark = submitTestRemark;
	}
	public String getTestRemark() {
		return testRemark;
	}
	public void setTestRemark(String testRemark) {
		this.testRemark = testRemark;
	}
}

==> xlniuxdata-vipgame-1.0.65-20170601.060151-85-sources.jar: com/xunlei/niux/data/vipgame/vo/mobilegameapkversion/MobileGameChannelApk.java <==
package com.xunlei.niux.data.vipgame.vo.mobilegameapkversion;

import com.ferret.common.dao.annotation.Table;

@Table(tableName="mobileGameChannelApk",pkFieldName="channelApkId")
public class MobileGameChannelApk {
	private Long channelApkId;
	private Long apkId;
	private String channelId;
	private String channelApkName;
	private String packageTime;
	private String downLoadLink;
	private String channleApkStatus;
	private String testUser;
	private String testTime;
	private String submitTestRemark;
	private String testRemark;
	private String muliPhotoUrl;
	private Integer isWDJGame;
	
	
	public String getMuliPhotoUrl() {
		return muliPhotoUrl;
	}
	public void setMuliPhotoUrl(String muliPhotoUrl) {
		this.muliPhotoUrl = muliPhotoUrl;
	}
	public Long getChannelApkId() {
		return channelApkId;
	}
	public void setChannelApkId(Long channelApkId) {
		this.channelApkId = channelApkId;
	}
	public Long getApkId() {
		return apkId;
	}
	public void setApkId(Long apkId) {
		this.apkId = apkId;
	}
	public String getChannelId() {
		return channelId;
	}
	public void setChannelId(String channelId) {
		this.channelId = channelId;
	}
	public String getChannelApkName() {
		return channelApkName;
	}
	public void setChannelApkName(String channelApkName) {
		this.channelApkName = channelApkName;
	}
	public String getPackageTime() {
		return packageTime;
	}
	public void setPackageTime(String packageTime) {
		this.packageTime = packageTime;
	}
	public String getDownLoadLink() {
		return downLoadLink;
	}
	public void setDownLoadLink(String downLoadLink) {
		this.downLoadLink = downLoadLink;
	}
	public String getChannleApkStatus() {
		return channleApkStatus;
	}
	public void setChannleApkStatus(String channleApkStatus) {
		this.channleApkStatus = channleApkStatus;
	}
	public String getTestUser() {
		return testUser;
	}
	public void setTestUser(String testUser) {
		this.testUser = testUser;
	}
	public String getTestTime() {
		return testTime;
	}
	public void setTestTime(String testTime) {
		this.testTime = testTime;
	}
	public String getSubmitTestRemark() {
		return submitTestRemark;
	}
	public void setSubmitTestRemark(String submitTestRemark) {
		this.submitTestRemark = submitTestRemark;
	}
	public String getTestRemark() {
		return testRemark;
	}
	public void setTestRemark(String testRemark) {
		this.testRemark = testRemark;
	}

	public Integer getIsWDJGame() {
		return isWDJGame;
	}

	public void setIsWDJGame(Integer isWDJGame) {
		this.isWDJGame = isWDJGame;
	}
}
